aboutsummaryrefslogtreecommitdiff
path: root/js/lib/ui.js
diff options
context:
space:
mode:
Diffstat (limited to 'js/lib/ui.js')
-rw-r--r--js/lib/ui.js26
1 files changed, 3 insertions, 23 deletions
diff --git a/js/lib/ui.js b/js/lib/ui.js
index 692311d73..fd20acbd1 100644
--- a/js/lib/ui.js
+++ b/js/lib/ui.js
@@ -11,7 +11,7 @@ elgg.ui.init = function () {
$('.elgg-system-messages li').animate({opacity: 0.9}, 6000);
$('.elgg-system-messages li').fadeOut('slow');
- $('.elgg-toggler').live('click', elgg.ui.toggles);
+ $('[rel=toggle]').live('click', elgg.ui.toggles);
$('[rel=popup]').live('click', elgg.ui.popsUp);
@@ -27,8 +27,8 @@ elgg.ui.init = function () {
/**
* Toggles an element based on clicking a separate element
*
* Use .elgg-toggler on the toggler element
* Set the href to target the item you want to toggle (<a class="elgg-toggler" href="#id-of-target">)
*
* @param {Object} event
* @return void
@@ -228,25 +228,6 @@ elgg.ui.requiresConfirmation = function(e) {
};
/**
- * Repositions the likes popup
- *
- * @param {String} hook 'getOptions'
- * @param {String} type 'ui.popup'
- * @param {Object} params An array of info about the target and source.
- * @param {Object} options Options to pass to
- *
- * @return {Object}
- */
-elgg.ui.likesPopupHandler = function(hook, type, params, options) {
- if (params.target.hasClass('elgg-likes-list')) {
- options.my = 'right bottom';
- options.at = 'left top';
- return options;
- }
- return null;
-};
-
-/**
* Repositions the login popup
*
* @param {String} hook 'getOptions'
@@ -266,5 +247,4 @@ elgg.ui.LoginHandler = function(hook, type, params, options) {
};
elgg.register_hook_handler('init', 'system', elgg.ui.init);
-elgg.register_hook_handler('getOptions', 'ui.popup', elgg.ui.likesPopupHandler);
elgg.register_hook_handler('getOptions', 'ui.popup', elgg.ui.LoginHandler); \ No newline at end of file
@@ -27,8 +27,8 @@ elgg.ui.init = function () {
* Toggles an element based on clicking a separate element
*
- * Use .elgg-toggler on the toggler element
- * Set the href to target the item you want to toggle (<a class="elgg-toggler" href="#id-of-target">)
+ * Use rel="toggle" on the toggler element
+ * Set the href to target the item you want to toggle (<a rel="toggle" href="#id-of-target">)
*
* @param {Object} event